@@ -708,7 +708,7 @@ class LogicAppPipelineConfigManager:
         temp = "./temp"
         FolderUtilities.make_dir(temp)
 
-        temp_file = os.path.join(temp, self.REMOTE_FILE_NAME)
+        temp_file = os.path.join(temp, pipeline_file_name)
 
         with open(temp_file, 'w') as outfile:
             json.dump(data, outfile)
@@ -1065,11 +1065,17 @@ class ConfigProvider:
     def load(self):
         data = self._load_data()
 
-        self.AML_COMPUTE_CLUSTER_NAME = data["Azure"]["AmlCompute"]["ClusterName"]
-        self.AML_COMPUTE_CLUSTER_MIN_NODES = data["Azure"]["AmlCompute"]["ClusterMinNode"]
-        self.AML_COMPUTE_CLUSTER_MAX_NODES = data["Azure"]["AmlCompute"]["ClusterMaxNode"]
-        self.AML_COMPUTE_CLUSTER_VM_TYPE = data["Azure"]["AmlCompute"]["ClusterType"]
-        self.IDLE_SECONDS_BEFORE_SCALEDOWN = data["Azure"]["AmlCompute"]["IdleSecondes_Before_Scaledown"]
+        #AmlComputes
+        self.AML_COMPUTE_VEC_CLUSTER_NAME = data["Azure"]["AmlComputes"]["Vectorization"]["ClusterName"]
+        self.AML_COMPUTE_VEC_CLUSTER_VM_TYPE = data["Azure"]["AmlComputes"]["Vectorization"]["ClusterType"]
+        self.AML_COMPUTE_DS_CLUSTER_NAME = data["Azure"]["AmlComputes"]["DataScience"]["ClusterName"]
+        self.AML_COMPUTE_DS_CLUSTER_VM_TYPE = data["Azure"]["AmlComputes"]["DataScience"]["ClusterType"]
+        self.AML_COMPUTE_SAMPLING_CLUSTER_NAME = data["Azure"]["AmlComputes"]["Sampling"]["ClusterName"]
+        self.AML_COMPUTE_SAMPLING_DS_CLUSTER_VM_TYPE = data["Azure"]["AmlComputes"]["Sampling"]["ClusterType"]
+
+        self.AML_COMPUTE_CLUSTER_MIN_NODES = data["Azure"]["AmlComputes"]["ClusterMinNode"]
+        self.AML_COMPUTE_CLUSTER_MAX_NODES = data["Azure"]["AmlComputes"]["ClusterMaxNode"]
+        self.IDLE_SECONDS_BEFORE_SCALEDOWN = data["Azure"]["AmlComputes"]["IdleSecondes_Before_Scaledown"]
 
         #StorageAccount
         self.BLOB_DATASTORE_NAME = data["Azure"]["StorageAccount"]["BlobDatastoreName"]
@@ -1085,12 +1091,14 @@ class ConfigProvider:
 
         #ExperimentName
         #self.EXPERIMENT_NAME = data["Azure"]["Azureml"]["Experiment"]["Name"]
-        
+        self.EXPERIMENT_VEC_NAME = data["Azure"]["Azureml"]["Experiments"]["Vectorization"]["Name"]
         self.EXPERIMENT_DS_NAME = data["Azure"]["Azureml"]["Experiments"]["DataScience"]["Name"]
         self.EXPERIMENT_SAMPLING_NAME = data["Azure"]["Azureml"]["Experiments"]["Sampling"]["Name"]
         
         #self.PIPELINE_NAME = data["Azure"]["Azureml"]["Pipeline"]["Name"]
 
+        self.PIPELINE_VEC_NAME = data["Azure"]["Azureml"]["Pipelines"]["Vectorization"]["Name"]
+        self.PIPELINE_VEC_ENDPOINT = data["Azure"]["Azureml"]["Pipelines"]["Vectorization"]["EndPoint"]
         self.PIPELINE_DS_NAME = data["Azure"]["Azureml"]["Pipelines"]["DataScience"]["Name"]
         self.PIPELINE_DS_ENDPOINT = data["Azure"]["Azureml"]["Pipelines"]["DataScience"]["EndPoint"]
         self.PIPELINE_SAMPLING_NAME = data["Azure"]["Azureml"]["Pipelines"]["Sampling"]["Name"]
